FaceIdService class
Constructors
- FaceIdService(double? threshold, int? scanSteps, int? livenessMin, int? livenessMax, FaceDetectorMode? faceDetectorMode)
Properties
- faceDetectorMode ↔ FaceDetectorMode?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- livenessMax ↔ int?
-
getter/setter pair
- livenessMin ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanSteps ↔ int?
-
getter/setter pair
- threshold ↔ double?
-
getter/setter pair
Methods
-
create(
CameraController controller) → Future< String?> -
initialize(
) → Future< void> -
liveness(
CameraController controller) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
List< String?> ? currentBase64List, List<String?> ? storedBase64List, {bool? onMatch}) → Future<bool>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited